@@ -3,6 +3,7 @@ from __future__ import annotations
 import secrets
 import time
 import typing
+
 from starlette.requests import HTTPConnection
 
 from starsessions.exceptions import SessionNotLoaded
@@ -100,7 +101,8 @@ class SessionHandler:
         self.metadata: typing.Optional[SessionMetadata] = None
 
     async def load(self) -> None:
-        if self.is_loaded:  # don't refresh existing session, it may contain user data
+        # don't refresh existing session, it may contain user data
+        if self.is_loaded:  # pragma: nocover, IDK how to test it :(
             return
 
         self.is_loaded = True
@@ -114,7 +116,11 @@ class SessionHandler:
             )
 
         # read and merge metadata
-        metadata = {"lifetime": self.lifetime, "created": time.time(), "last_access": time.time()}
+        metadata = {
+            "lifetime": self.lifetime,
+            "created": time.time(),
+            "last_access": time.time(),
+        }
         metadata.update(data.pop("__metadata__", {}))
         metadata.update({"last_access": time.time()})  # force update
         self.metadata = metadata  # type: ignore[assignment]
