@@ -1,7 +1,8 @@
 import functools
 import typing
+import warnings
+
 from redis.asyncio.client import Redis
-from redis.asyncio.utils import from_url
 
 from starsessions.exceptions import ImproperlyConfigured
 from starsessions.stores.base import SessionStore
@@ -11,19 +12,13 @@ def prefix_factory(prefix: str, key: str) -> str:
     return prefix + key
 
 
-if typing.TYPE_CHECKING:
-    BaseRedis = Redis[bytes]
-else:
-    BaseRedis = Redis
-
-
 class RedisStore(SessionStore):
     """Stores session data in a Redis server."""
 
     def __init__(
         self,
         url: typing.Optional[str] = None,
-        connection: typing.Optional[BaseRedis] = None,
+        connection: typing.Optional[Redis] = None,
         prefix: typing.Union[typing.Callable[[str], str], str] = "starsessions.",
         gc_ttl: int = 3600 * 24 * 30,
     ) -> None:
@@ -46,13 +41,17 @@ class RedisStore(SessionStore):
         self.gc_ttl = gc_ttl
         self.prefix: typing.Callable[[str], str] = prefix
         if connection:
-            self._connection: BaseRedis = connection
+            self._connection: Redis = connection
         else:
             assert url
-            self._connection = from_url(url)
+            warnings.warn(
+                "starsessions.stores.redis.RedisStore: 'url' argument is deprecated, use 'connection' instead.",
+                DeprecationWarning,
+            )
+            self._connection = Redis.from_url(url)
 
     async def read(self, session_id: str, lifetime: int) -> bytes:
-        value = await self._connection.get(self.prefix(session_id))
+        value: bytes = await self._connection.get(self.prefix(session_id))
         if value is None:
             return b""
         return value
@@ -70,7 +69,3 @@ class RedisStore(SessionStore):
 
     async def remove(self, session_id: str) -> None:
         await self._connection.delete(self.prefix(session_id))
-
-    async def exists(self, session_id: str) -> bool:
-        result: int = await self._connection.exists(self.prefix(session_id))
-        return result > 0
